@@ -385,12 +385,7 @@ class Parameter(BaseModel):
 class RequestFile(BaseModel):
     schema = "RequestFileSchema"
 
-    def __init__(
-        self,
-        storage_type=None,
-        filename=None,
-        id=None,
-    ):
+    def __init__(self, storage_type=None, filename=None, id=None):
         self.storage_type = storage_type
         self.filename = filename
         self.id = id
@@ -419,11 +414,15 @@ class File(BaseModel):
         chunks=None,
         chunk_size=None,
         owner=None,
+        job=None,
+        request=None,
     ):
         self.id = id
         self.owner_id = owner_id
         self.owner_type = owner_type
         self.owner = owner
+        self.job = job
+        self.request = request
         self.updated_at = updated_at
         self.file_name = file_name
         self.file_size = file_size
@@ -455,10 +454,7 @@ class FileChunk(BaseModel):
         return self.data
 
     def __repr__(self):
-        return "<FileChunk: file_id=%s, offset=%s>" % (
-            self.file_id,
-            self.offset,
-        )
+        return "<FileChunk: file_id=%s, offset=%s>" % (self.file_id, self.offset)
 
 
 class FileStatus(BaseModel):
@@ -602,6 +598,7 @@ class Request(RequestTemplate):
         created_at=None,
         error_class=None,
         metadata=None,
+        hidden=None,
         updated_at=None,
         has_parent=None,
         requester=None,
@@ -623,6 +620,7 @@ class Request(RequestTemplate):
         self.children = children
         self.output = output
         self._status = status
+        self.hidden = hidden
         self.created_at = created_at
         self.updated_at = updated_at
         self.error_class = error_class
@@ -1300,13 +1298,7 @@ class CronTrigger(BaseModel):
 class FileTrigger(BaseModel):
     schema = "FileTriggerSchema"
 
-    def __init__(
-        self,
-        pattern=None,
-        path=None,
-        recursive=None,
-        callbacks=None,
-    ):
+    def __init__(self, pattern=None, path=None, recursive=None, callbacks=None):
         self.pattern = pattern
         self.path = path
         self.recursive = recursive
